



cd "C:/JMCB_Direct_Lenders"

	use "Data\Dataset_BanerjeeSerena_Regressions_FullyUpdated.dta", clear
	

	keep ULender_ONonBank ULender_ID ULender_CommonName
	
	gen NumberLoans=1
	

	replace ULender_ONonBank=0 if ULender_ID=="5043337728"

	replace ULender_ONonBank=0 if ULender_ID=="5043337560"

	gen Type="Bank" if ULender_ONonBank==0
	
		replace Type="Direct Lender" if ULender_ONonBank==1

	collapse (sum) NumberLoans, by(  ULender_ID Type)
	
	gen DirectLender=1 if Type=="Direct Lender"
	gen Bank=1 if Type=="Bank"

	
	keep if NumberLoans>100
	
	bysort ULender_ID: gen Dup2=_n
	
	by ULender_ID: egen M=max(Dup2)
	drop if M!=1
	
	drop Dup2 M
	
	


save "Data\List_Bank_VS_DirectLenders.dta", replace



import excel "Data\Lenders_balance_sheets\Lender_dataset_reuters_fundamentals_with_MV.xlsx", sheet("Sheet1") firstrow clear



save "Data\Lender_dataset_MV.dta", replace

use "Data\Lender_dataset_MV.dta", clear




	tostring Instrument, replace

	gen ULender_ID=Instrument
	

	

	merge m:1 ULender_ID using "Data\List_Bank_VS_DirectLenders.dta"
	
		keep if _merge==3
		drop _merge
		
	merge m:1 ULender_ID using "Data\InvestmentBank.dta"
		drop if _merge==2
		drop _merge
	

	replace TotalDeposits=0 if TotalDeposits==.
	


	
	* Referee comment to define leverage differently
	gen Leverage=(TotalAssets-TotalEquity)/ TotalEquity
	
	gen MktLeverage=(TotalAssets-TotalEquity) / CompanyMarketCap

	gen STLeverage=(TotalAssets-TotalEquity-TotalLongTermDebt)/ (TotalAssets-TotalEquity)
	
	gen PolicyLiabilities2 = PolicyLiabilities
	replace PolicyLiabilities2=0 if PolicyLiabilities==.
	
	gen MktLeverage2=(TotalAssets-TotalEquity-PolicyLiabilities2)/ (CompanyMarketCap)
	
	gen STLeverage2=(TotalAssets-TotalEquity-TotalLongTermDebt-PolicyLiabilities2)/ (TotalAssets-TotalEquity)
	
	
	save "Data\Lender_dataset_MV_merged.dta", replace
	
	
	* Have some banks with zero leverage which is odd
	drop if Leverage<=0

	
	gen InvestmentBank=1 if TypeLender=="Investment bank" & DirectLender!=1
	replace  Bank=0 if TypeLender=="Investment bank"
	
	foreach var in Leverage MktLeverage STLeverage {
	
		gen `var'_DL=`var' if DirectLender==1
		gen `var'_B=`var' if Bank==1 
		gen `var'_IB=`var' if InvestmentBank==1 
	}
	
	foreach var in Leverage_DL Leverage_B Leverage_IB MktLeverage_DL MktLeverage_B MktLeverage_IB STLeverage_DL STLeverage_B STLeverage_IB{
		
		winsor2 `var', cuts(5 95) trim replace
		
	}
	
	


	
	graph box Leverage_DL Leverage_B Leverage_IB, nooutsides title("A. Total liabilities to book equity", size(small)) note("") graphregion(color(white)) ///
		ytitle("") legend(region(lcolor(none)) on order(1 "Direct lenders" 2 "Banks: deposit-taking" 3 "Banks: Investment banks") rows(1) size(small))
		
					graph export "Results\Graph_DirectLender_Leverage.pdf", replace
					graph save "Results\Graph_DirectLender_Leverage.gph", replace

	graph box MktLeverage_DL MktLeverage_B MktLeverage_IB, nooutsides title("B. Total liabilities to market equity", size(small)) note("") graphregion(color(white)) ///
		ytitle("") legend(region(lcolor(none)) on order(1 "Direct lenders" 2 "Banks: deposit-taking" 3 "Banks: Investment banks") rows(1) size(small))
		
					graph export "Results\Graph_DirectLender_MktLeverage.pdf", replace
					graph save "Results\Graph_DirectLender_MktLeverage.gph", replace
							

	graph box STLeverage_DL STLeverage_B STLeverage_IB, nooutsides title("C. Short-term liabilities to total liabilities", size(small)) note("") graphregion(color(white)) ///
		ytitle("") legend(region(lcolor(none)) on order(1 "Direct lenders" 2 "Banks: deposit-taking" 3 "Banks: Investment banks" ) rows(1) size(small))
		
					graph export "Results\Graph_DirectLender_MaturityTransformation.pdf", replace
					graph save "Results\Graph_DirectLender_MaturityTransformation.gph", replace
	
	

				
				
				
	grc1leg "Results\Graph_DirectLender_Leverage.gph" "Results\Graph_DirectLender_MktLeverage.gph" "Results\Graph_DirectLender_MaturityTransformation.gph", ///
	rows(1) cols(3)  graphregion(color(white)) legendfrom("Results\Graph_DirectLender_Leverage.gph")  iscale(1) imargins(0 0 0 0) name(grc1leg, replace)
	
	gr draw grc1leg, ysize(5) xsize(8)
	
				graph export "Results\Graph_BoxPlot.pdf", replace
				graph save "Results\Graph_BoxPlot.gph", replace
				

				
				
******************************
* Table of stats 
******************************

	foreach var in Leverage MktLeverage STLeverage{
		
		winsor2 `var', cuts(5 95) trim replace
		
	}

*Direct lenders
	************************** Used in paper
	tabstat Leverage MktLeverage STLeverage /// 
		if DirectLender==1, s(mean p25 median p75) save format(%3.2f)
	tabstatmat Dataset_Sample
	matrix Dataset_Sample=Dataset_Sample'
	
	mat coln Dataset_Sample = m{e}an p25 p50 p75 
	
	esttab matrix(Dataset_Sample, fmt(1 1 1 1)) using "Results/Dataset_Sample_DirectLenders.tex", ///
	   eqlabels(none) title("")  fragment  alignment(S)  /// 
		varlabels(Leverage "Book leverage" MktLeverage "Market leverage" STLeverage "Short-term liability ratio") replace 
		
* Banks
	************************** Used in paper
	tabstat Leverage MktLeverage STLeverage /// 
		if Bank==1 | InvestmentBank==1, s(mean p25 median p75) save format(%3.2f)
	tabstatmat Dataset_Sample
	matrix Dataset_Sample=Dataset_Sample'
	
	mat coln Dataset_Sample = m{e}an p25 p50 p75 
	
	esttab matrix(Dataset_Sample, fmt(1 1 1 1)) using "Results/Dataset_Sample_Banks.tex", ///
	   eqlabels(none) title("")  fragment  alignment(S)  /// 
		varlabels(Leverage "Book leverage" MktLeverage "Market leverage" STLeverage "Short-term liability ratio") replace 
				
				
*****************************************
* Graph on leverage by major DL type
*****************************************

merge m:1 ULender_ID using "Data/NewDependentVariable.dta"
	*merge m:1 LoanDealNumber using "Data/NewDependentVariable.dta"
	drop if _merge==2
	

drop if Bank==1 
drop if InvestmentBank==1 


	foreach var in Leverage MktLeverage STLeverage MktLeverage2 {
		
	
		gen `var'_FT=`var' if FundsTrusts==1
		gen `var'_SC=`var' if SecurityCommodityContracts==1 
		gen `var'_IC=`var' if InsuranceCompanies==1 
		gen `var'_MM=`var' if MachineryManufacturing==1
		gen `var'_CI=`var' if CreditIntermediaries==1 
	}
	
	foreach var in Leverage_FT Leverage_SC Leverage_IC Leverage_MM Leverage_CI MktLeverage_FT MktLeverage_SC MktLeverage_IC MktLeverage_MM MktLeverage_CI STLeverage_FT STLeverage_SC STLeverage_IC STLeverage_MM STLeverage_CI MktLeverage2_FT MktLeverage2_SC MktLeverage2_IC MktLeverage2_MM MktLeverage2_CI {
		
		winsor2 `var', cuts(5 95) trim replace
		
	}
	

				graph box STLeverage_FT STLeverage_SC STLeverage_IC STLeverage_MM STLeverage_CI, nooutsides title("C. Short-term liabilities to total liabilities", size(small)) note("") graphregion(color(white)) ///
		ytitle("") legend(region(lcolor(none)) on order(1 "FT" 2 "SC" 3 "IC" 4 "MM" 5 "CI") rows(1) size(small))
		
					graph export "Results\Graph_DL_Type_MaturityTransformation.pdf", replace
					graph save "Results\Graph_DL_Type_MaturityTransformation.gph", replace
				
					
				graph box MktLeverage2_FT MktLeverage2_SC MktLeverage2_IC MktLeverage2_MM MktLeverage2_CI, nooutsides title("D. Policyliability adjusted liabilities to market equity ", size(small)) note("") graphregion(color(white)) ///
		ytitle("") legend(region(lcolor(none)) on order(1 "FT" 2 "SC" 3 "IC" 4 "MM" 5 "CI") rows(1) size(small))
		
					graph export "Results\Graph_DL_Type_PolicyAdjMktLeverage.pdf", replace
					graph save "Results\Graph_DL_Type_PolicyAdjMktLeverage.gph", replace
					


gen LenderType_DL="Other"
replace LenderType_DL="FT" if FundsTrusts==1
replace LenderType_DL="SC" if SecurityCommodityContracts==1 
replace LenderType_DL="IC" if InsuranceCompanies==1 
replace LenderType_DL="MM" if MachineryManufacturing==1
replace LenderType_DL="CI" if CreditIntermediaries==1


	foreach var in MktLeverage2 STLeverage STLeverage2{
		
		winsor2 `var', cuts(5 95) trim replace
		
	}

collapse (median) MktLeverage2 STLeverage STLeverage2, by(LenderType_DL)
save "Data/Median_DL_MktLeverage_byType.dta", replace

*collapse (mean) MktLeverage2 STLeverage STLeverage2, by(LenderType_DL)
*save "Data/Mean_DL_MktLeverage_byType.dta", replace


				
