# Figure_6_DL_Type_Estimate_Leverage.r


setwd("C:/JMCB_Direct_Lenders/")

library(readstata13)
library(data.table)
library(tidyverse)
library(patchwork)
library(sandwich)
library(lmtest)

# market leverage ratios computed by Figure_2_Funding_Model_Table_4_Lender_Attributes
df.median <- read.dta13("Data/Median_DL_MktLeverage_byType.dta")
# df.median <- read.dta13("Data/Mean_DL_MktLeverage_byType.dta")

df.median$LenderType_DL <- ifelse(df.median$LenderType_DL=="MM", "NF", df.median$LenderType_DL)

# Estimates from Table 9: Types of direct lenders
LenderType_DL <- c("FT", "SC", "IC", "NF", "CI")
mp_shock <- c(0.116, 0.066, 0.167, 0.083, 0.061)
mp_shock_se <- c(0.04, 0.03, 0.04, 0.05, 0.02)
news_shock <- c(-0.146, -0.059, -0.073, -0.087, -0.053)
news_shock_se <- c(0.04, 0.03, 0.04, 0.05, 0.03)


df.estimates <- tibble(
  LenderType_DL,
  mp_shock,
  mp_shock_se,
  news_shock,
  news_shock_se
)

df <- merge(df.median, df.estimates, by="LenderType_DL")

p1 <- ggplot(df, aes(MktLeverage2, mp_shock)) + geom_point() + geom_smooth(method="lm", se=F, linetype="dashed", alpha=0.6, colour="grey") + theme_classic() +
  xlab(NULL) + ylab("Estimate") + labs(subtitle = "Pure monetary policy shocks") + theme(plot.margin=unit(c(0,0,-5,0), "mm")) + 
  geom_text(aes(label=LenderType_DL), vjust = 0, nudge_y = -0.007)
p1

p2 <- ggplot(df, aes(MktLeverage2, news_shock)) + geom_point() + geom_smooth(method="lm", se=F, linetype="dashed", alpha=0.6, colour="grey") + theme_classic() +
  xlab(NULL) + ylab(NULL) + labs(subtitle = "Information shocks") + theme(plot.margin=unit(c(0,0,-5,0), "mm")) +
  geom_text(aes(label=LenderType_DL), vjust = 0, nudge_y = -0.007)
p2

result <- p1 + p2


gt <- patchwork::patchworkGrob(result)
finalplot <- gridExtra::grid.arrange(gt, bottom = "Market leverage")
grid::grid.draw(finalplot)
ggsave("Results/Graph_DL_Leverage_mp_sensitivity.pdf", finalplot, width = 6.5, height = 3.8)


p3 <- ggplot(df, aes(STLeverage2, mp_shock)) + geom_point() + geom_smooth(method="lm", se=F, linetype="dashed", alpha=0.6, colour="grey") + theme_classic() +
  xlab(NULL) + ylab("Estimate") + labs(subtitle = "Pure monetary policy shocks") + theme(plot.margin=unit(c(0,0,-5,0), "mm")) + 
  geom_text(aes(label=LenderType_DL), vjust = 0, nudge_y = -0.007)
p3

p4 <- ggplot(df, aes(STLeverage2, news_shock)) + geom_point() + geom_smooth(method="lm", se=F, linetype="dashed", alpha=0.6, colour="grey") + theme_classic() +
  xlab(NULL) + ylab(NULL) + labs(subtitle = "Information shocks") + theme(plot.margin=unit(c(0,0,-5,0), "mm")) +
  geom_text(aes(label=LenderType_DL), vjust = 0, nudge_y = -0.007)
p4

result2 <- p3 + p4
result2



gt2 <- patchwork::patchworkGrob(result2)
finalplot2 <- gridExtra::grid.arrange(gt2, bottom = "Short-term liabiltiy ratio")
grid::grid.draw(finalplot2)
ggsave("Results/Graph_DL_STLeverage_mp_sensitivity.pdf", finalplot2, width = 6.5, height = 3.8)

