

cd "C:\JMCB_Direct_Lenders\"


use "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital.dta", clear

keep LoanDealNumber L_ClosingDate L_Description L_UseofProceeds

save "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_L_UseofProceeds.dta", replace


use "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_Compressed_FINAL.dta", clear

drop year month day

gen year=year(L_ClosingDate)
gen month=month(L_ClosingDate)
gen day=day(L_ClosingDate)

merge m:1 year month day using "Data/Stock_returns_30_60_90_UST2y_MLHYSpreads.dta"
	drop if _merge==2
	drop _merge

*winsor2 SP500_PI_90_xs ,cuts(2.5 97.5) 

merge m:1 year QuarterI using "Data/US_GDP.dta"
	drop if _merge==2
	drop _merge
	
logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
	Firm_LeverageRatio Firm_FixedAssetsRatio    ///
	lgdp_growth ML_HY_Spread  ///
	UST2y UST2y_90 SP500_PI_90_xs MonetaryShock_win if HighestCapitalBank==1 & L_TermLoan==1, vce(robust)
			
gen Sample_A=1 if e(sample)

keep if Sample_A==1
	
merge 1:1 LoanDealNumber L_ClosingDate using "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_L_UseofProceeds.dta"
	drop if _merge==2
	drop _merge


* define cluster for SEs
egen time=group(L_ClosingDate)
egen issuance_ym=group(L_YearIMonth) /* issuance year x month */
egen issuance_yq=group(L_Iquarter)



gen UseofProceeds=L_UseofProceeds

do "Code/z_UseOfProceeds.do" 

save "Data\Robustness_Dataset.dta", replace


cd "C:\JMCB_Direct_Lenders\Results\"


*ROBUSTNESS 1. INFLUENTIAL SECTORS*

	gen Loop_Indicator=0 if Firm_TRBCEconomicSector!="."
		replace Loop_Indicator=1 if  Firm_TRBCEconomicSector=="Basic Materials"
		replace Loop_Indicator=2 if  Firm_TRBCEconomicSector=="Consumer Cyclicals"
		replace Loop_Indicator=3 if  Firm_TRBCEconomicSector=="Consumer Non-Cyclicals"
		replace Loop_Indicator=4 if  Firm_TRBCEconomicSector=="Energy"
		replace Loop_Indicator=5 if  Firm_TRBCEconomicSector=="Financials"
		replace Loop_Indicator=6 if  Firm_TRBCEconomicSector=="Healthcare"
		replace Loop_Indicator=7 if  Firm_TRBCEconomicSector=="Industrials"
		replace Loop_Indicator=8 if  Firm_TRBCEconomicSector=="Technology"
		replace Loop_Indicator=9 if  Firm_TRBCEconomicSector=="Telecommunications Services"
		replace Loop_Indicator=10 if  Firm_TRBCEconomicSector=="Utilities"

matrix define Betas_mps=J(10,1,1)
matrix define SD_mps=J(10,1,1)

matrix define Betas_ns_g=J(10,1,1)
matrix define SD_ns_g=J(10,1,1)

matrix define Betas_ns_nfc=J(10,1,1)
matrix define SD_ns_nfc=J(10,1,1)

matrix define sector_loop_id=J(10,1,1)



*No time dummies*
		*USD term loans*
		
		local i=1
		
		while `i'<11 {
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y SP500_PI_90_xs mp_shock_b2_90_win news_shock_b2_90_win UST2y_90  if HighestCapitalBank==1 & ///
			L_TermLoan==1 & Loop_Indicator!=`i' & Firm_TRBCEconomicSector!=".", vce(cluster time)
			
		
				matrix BETA=e(b)
					local b_mps=BETA[1,12]
					local b_ns_g=BETA[1,13]
					
				matrix SD=e(V)	
					local sd_mps=_se[mp_shock_b2_90_win]
					local sd_ns_g=_se[news_shock_b2_90_win]
					
				
		matrix Betas_mps[`i',1]=`b_mps'
		matrix Betas_ns_g[`i',1]=`b_ns_g'
		
		matrix SD_mps[`i',1]=`sd_mps'
		matrix SD_ns_g[`i',1]=`sd_ns_g'
		
		matrix sector_loop_id[`i',1]=`i'
		
		local i=`i'+1
		di `i'
		
				
}


foreach var in Betas_mps Betas_ns_g  SD_mps SD_ns_g sector_loop_id  {
			svmat `var', names(`var'_plot)
}

gen mps_plus1sd=Betas_mps+1.96*SD_mps
gen mps_minus1sd=Betas_mps-1.96*SD_mps

gen ns_g_plus1sd=Betas_ns_g+1.96*SD_ns_g
gen ns_g_minus1sd=Betas_ns_g-1.96*SD_ns_g

gen mps_plus90=Betas_mps+1.64*SD_mps
gen mps_minus90=Betas_mps-1.64*SD_mps

gen ns_g_plus90=Betas_ns_g+1.64*SD_ns_g
gen ns_g_minus90=Betas_ns_g-1.64*SD_ns_g
 
 

sort Betas_mps // Sort from high to low of monetary policy shocks
gen Grid=_n in 1/10

/* 
Grid sectors for footnote
1 = "Technology"
2 = "Consumer Cyclicals"
3 = "Healthcare" (insignificant at 95% level up to here if dropped)
4 = "Utilities"
5 = "Telecommunications Services"
6 = "Energy"
7 = "Industrials"
8 = "Financials"
9 = "Consumer Non-Cyclicals"
10 = "Basic Materials"

*/

logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio ///
	Firm_FixedAssetsRatio lgdp_growth ML_HY_Spread  UST2y SP500_PI_90_xs /// 
	mp_shock_b2_90_win news_shock_b2_90_win UST2y_90  if HighestCapitalBank==1 ///
	& L_TermLoan==1 & Firm_TRBCEconomicSector!=".", vce(cluster time)


* Input by hand from 000_Table_I_Baseline - table C
gen yline1=0.051
gen yline2=-0.058
				
drop if Grid==0


 
 twoway (line Betas_mps Grid in 1/10, title("Pure monetary", size(medium))  graphregion(color(white)) ///
	 lcolor(red) lpattern(solid) lwidth(thick)) || (line mps_plus1sd Grid  in 1/10, lcolor(black) lpattern(dash)) || (line mps_plus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || (line mps_minus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || /// 
	 (line mps_minus1sd Grid  in 1/10, lcolor(black) lpattern(dash) legend(size(small) ///  
	 order(1 "Influential sector analysis" 6 "Baseline regression" 2 "95% CI" 3 "90%CI" ) rows(2) region(lstyle(none)))) || /// 
	 (line yline1 Grid  in 1/10, lcolor(blue)  lwidth(thick) lpattern(dash) xlabel(1(2)10))
	 
		graph export R_I_MonetaryPolicyShock.eps, replace				
		graph save R_I_MonetaryPolicyShock.gph, replace

 twoway (line Betas_ns_g Grid in 1/10, title("Information shocks", size(medium))  graphregion(color(white)) ///
	 lcolor(red) lpattern(solid) lwidth(thick)) || (line ns_g_plus1sd Grid  in 1/10, lcolor(black) lpattern(dash)) || (line ns_g_plus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || (line ns_g_minus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || /// 
	 (line ns_g_minus1sd Grid  in 1/10, lcolor(black) lpattern(dash) legend(size(small) ///  
	 order(1 "Influential sector analysis" 6 "Baseline regression" 2 "95% CI" 3 "90%CI" ) rows(2) region(lstyle(none)))) || /// 
	 (line yline2 Grid  in 1/10, lcolor(blue)  lwidth(thick) lpattern(dash) xlabel(1(2)10))
	 
		graph export R_I_NewsShock.eps, replace				
		graph save R_I_NewsShock.gph, replace			
			

		*cd "C:\Users\jo003614\2019_nonbanklending\Results\July2021"
		cd "C:\Users\ry002679\Dropbox (BIS)\JMCB_Direct_Lenders\Results"
		grc1leg R_I_MonetaryPolicyShock.gph R_I_NewsShock.gph , rows(1) cols(2) /// 
			iscale(1) ysize(4) xsize(8)  graphregion(color(white)) legendfrom(R_I_MonetaryPolicyShock.gph)

		graph export R_I_Graph_FINAL.eps, replace				
		graph save R_I_Graph_FINAL.gph, replace	
	

*ROBUSTNESS 2. USE OF PROCEEDS

cd "C:\JMCB_Direct_Lenders\"
use "Data\Robustness_Dataset.dta", clear

	logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio ///
		Firm_FixedAssetsRatio  lgdp_growth ML_HY_Spread  UST2y SP500_PI_90_xs /// 
		mp_shock_b2_90_win news_shock_b2_90_win UST2y_90   if HighestCapitalBank==1 ///
		& L_TermLoan==1 & Firm_TRBCEconomicSector!=".", vce(cluster time)
	
	tab UseofProceeds if e(sample)
	
	
	gen Loop_Indicator=0 if UseofProceeds!="."
		replace Loop_Indicator=1 if  UseofProceeds=="Debt management"
		replace Loop_Indicator=2 if  UseofProceeds=="Fixed capital formation"
		replace Loop_Indicator=3 if  UseofProceeds=="General Corp. Purp."
		*replace Loop_Indicator=4 if  UseofProceeds=="Refinancing"*
		replace Loop_Indicator=4 if  UseofProceeds=="Working Capital"

		
		
matrix define Betas_mps=J(4,1,1)
matrix define SD_mps=J(4,1,1)

matrix define Betas_ns_g=J(4,1,1)
matrix define SD_ns_g=J(4,1,1)

matrix define sector_loop_id=J(10,1,1)


cd "C:\JMCB_Direct_Lenders\Results\"
*No time dummies*
		*USD term loans*
		
		local i=1
		
		while `i'<5 {
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y SP500_PI_90_xs mp_shock_b2_90_win news_shock_b2_90_win UST2y_90  if HighestCapitalBank==1 & ///
			L_TermLoan==1 & Loop_Indicator!=`i' & UseofProceeds!=".", vce(cluster time)
			
		
				matrix BETA=e(b)
					local b_mps=BETA[1,12]
					local b_ns_g=BETA[1,13]
					
				matrix SD=e(V)	
					local sd_mps=_se[mp_shock_b2_90_win]
					local sd_ns_g=_se[news_shock_b2_90_win]
				
		matrix Betas_mps[`i',1]=`b_mps'
		matrix Betas_ns_g[`i',1]=`b_ns_g'
		
		matrix SD_mps[`i',1]=`sd_mps'
		matrix SD_ns_g[`i',1]=`sd_ns_g'
		
		matrix sector_loop_id[`i',1]=`i'
		
		local i=`i'+1
		di `i'
		
				
}


foreach var in Betas_mps Betas_ns_g  SD_mps SD_ns_g sector_loop_id  {
			svmat `var', names(`var'_plot)
}

gen mps_plus1sd=Betas_mps+1.96*SD_mps
gen mps_minus1sd=Betas_mps-1.96*SD_mps

gen ns_g_plus1sd=Betas_ns_g+1.96*SD_ns_g
gen ns_g_minus1sd=Betas_ns_g-1.96*SD_ns_g


gen mps_plus90=Betas_mps+1.64*SD_mps
gen mps_minus90=Betas_mps-1.64*SD_mps

gen ns_g_plus90=Betas_ns_g+1.64*SD_ns_g
gen ns_g_minus90=Betas_ns_g-1.64*SD_ns_g


sort Betas_mps
gen Grid=_n in 1/4

/*
Grid use of proceeds for footnote
1 = "Fixed capital formation" (MP shocks insiginficant at 95% level if dropped)
2 = "Debt management"
3 = "Working Capital"
4 = "General Corp. Purp."
*/


gen yline1=0.051
gen yline2=-0.058



 twoway (line Betas_mps Grid in 1/4, title("Pure monetary shocks", size(medium))  graphregion(color(white)) ///
	 lcolor(red) lpattern(solid) lwidth(thick)) || (line mps_plus1sd Grid  in 1/4, lcolor(black) lpattern(dash)) ||  (line mps_plus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || (line mps_minus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || /// 
	 (line mps_minus1sd Grid  in 1/4, lcolor(black) lpattern(dash) legend(size(small) ///  
	 order(1 "Use of proceeds"  6 "Baseline regression" 2 "95% CI" 3 "90%CI" ) rows(2) region(lstyle(none)))) || /// 
	 (line yline1 Grid  in 1/4, lcolor(blue)  lwidth(thick) lpattern(dash) xlabel(1(1)4))
	 
		graph export R_II_MonetaryPolicyShock.eps, replace				
		graph save R_II_MonetaryPolicyShock.gph, replace

*sort Betas_ns_g
 twoway (line Betas_ns_g Grid in 1/4, title("Information shocks", size(medium))  graphregion(color(white)) ///
	 lcolor(red) lpattern(solid) lwidth(thick)) || (line ns_g_plus1sd Grid  in 1/4, lcolor(black) lpattern(dash)) || (line ns_g_plus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || (line ns_g_minus90 Grid  in 1/10, lcolor(black) lpattern(dot)) || /// 
	 (line ns_g_minus1sd Grid  in 1/4, lcolor(black) lpattern(dash) legend(size(small) ///  
	 order(1 "Use of proceeds" 6 "Baseline regression" 2 "95% CI" 3 "90%CI" ) rows(2) region(lstyle(none)))) || /// 
	 (line yline2 Grid  in 1/4, lcolor(blue)  lwidth(thick) lpattern(dash) xlabel(1(1)4))
	 
		graph export R_II_NewsShock.eps, replace				
		graph save R_II_NewsShock.gph, replace			
		
		

	
		cd "C:\JMCB_Direct_Lenders\Results\"
		grc1leg R_II_MonetaryPolicyShock.gph R_II_NewsShock.gph , rows(1) cols(2) /// 
			iscale(1) ysize(4) xsize(8)  graphregion(color(white)) legendfrom(R_II_MonetaryPolicyShock.gph)
			
		graph export R_II_Graph_FINAL.eps, replace				
		graph save R_II_Graph_FINAL.gph, replace
		
