

cd "C:\JMCB_Direct_Lenders\"


use "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_Compressed_FINAL.dta", clear



drop year month day

gen year=year(L_ClosingDate)
gen month=month(L_ClosingDate)
gen day=day(L_ClosingDate)

merge m:1 year month day using "Data/Stock_returns_30_60_90_UST2y_MLHYSpreads.dta"
	drop if _merge==2
	drop _merge

winsor2 SP500_PI_90_xs ,cuts(2.5 97.5) 

merge m:1 year QuarterI using "Data/US_GDP.dta"
	drop if _merge==2
	drop _merge




gen MonetaryShock30=mp_shock_b2_30+news_shock_b2_30
	
winsor2 mp_shock_b2_30 news_shock_b2_30 MonetaryShock30, cuts(2.5 97.5) suffix (_win)

replace mp_shock_b2_30_win=mp_shock_b2_30_win/100
replace news_shock_b2_30_win=news_shock_b2_30_win/100
replace MonetaryShock30_win=MonetaryShock30_win/100


replace mp_shock_b2_30 = -mp_shock_b2_30 if L_YearI == 2006	| L_YearIMonth == tm(2017m1)



gen MonetaryShock60=mp_shock_b2_60+news_shock_b2_60
	
winsor2 mp_shock_b2_60 news_shock_b2_60 MonetaryShock60, cuts(2.5 97.5) suffix (_win)
replace mp_shock_b2_60_win=mp_shock_b2_60_win/100
replace news_shock_b2_60_win=news_shock_b2_60_win/100
replace MonetaryShock60_win=MonetaryShock60_win/100


foreach var in mp_shock_b2_30_win news_shock_b2_30_win{

	egen std_`var'=std(`var')
	
	rename `var' zBUp_`var'
	
	rename std_`var' `var'

}	


* define cluster for SEs
egen time=group(L_ClosingDate)
egen issuance_ym=group(L_YearIMonth) /* issuance year x month */
egen issuance_yq=group(L_Iquarter)
	


cd "Results\"


*TABLE 1. BASELINE A*

		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs MonetaryShock30_win if HighestCapitalBank==1 & L_TermLoan==1 , vce(cluster time)
			*US2YrMarket MonetaryShock_win if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 , vce(robust)
			
			gen Sample_A=1 if e(sample)
			
	*1.A.1 - plain model* 
	*logit NonBankLoan L_OriginalMaturity L_Amount US2YrMarket MonetaryShock_win if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
	logit NonBankLoan L_OriginalMaturity L_Amount UST2y UST2y_90 MonetaryShock30_win if HighestCapitalBank==1 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
		
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IA_1
		
				local TypeLoan="TL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_IA_1
				}
	
	*1.A.2 - basic controls* 
	logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio UST2y UST2y_90 MonetaryShock30_win if HighestCapitalBank==1 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*Firm_LeverageRatio Firm_FixedAssetsRatio US2YrMarket MonetaryShock_win if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*Firm_LeverageRatio Firm_FixedAssetsRatio US2YrMarket MonetaryShock_win if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
		
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IA_2
		
				local TypeLoan="TL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_IA_2
				}
	
		
	*1.A.3 - full model* 
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs MonetaryShock30_win if HighestCapitalBank==1 & L_TermLoan==1 , vce(cluster time)
			*US2YrMarket MonetaryShock_win if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 , vce(robust)
			
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IA_3
		
				local TypeLoan="TL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_IA_3
				}
				
				
				*Table I*
				# delimit ;
				esttab Model_IA_1 Model_IA_2 Model_IA_3  using robustness_Table_I_A_Baseline_shorterMPwindow.tex, label collabels(none) substitute(\_ _ panel ) 
				title("Monetary policy decisions and nonbank lending")
				 nodepvars mtitles(I II III IV) nonumbers star(* 0.10 ** 0.05 *** 0.01)
				fragment  alignment(S) eqlabels(none) varlabels(
				FedTarget "Fed target rate" NonBankLoan "Non-bank loan" UST2y "2 year interest rates" mp_shock_b2_30_win "Pure monetary shock"
				news_shock_b2_30_win "Information shock" MonetaryShock30_win "Monetary policy shock"
				L_OriginalMaturity "Loan maturity" L_Amount "Loan amount" L_OriginalMaturity "Loan maturity" L_NumberLenders "Number lenders"
				Firm_TotalAssets_USbn "Firm assets" Firm_EBITDARatio "Firm EBITDA ratio" Firm_QuickRatio "Firm quick ratio" 
				Firm_LeverageRatio "Firm leverage" Firm_FixedAssetsRatio  "Firm fixed assets ratio"
				 lgdp_growth "Global GDP growth"
				ML_HY_Spread "Merril-Lynch HY spread")			
				nogaps order(L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio Firm_FixedAssetsRatio lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs MonetaryShock_win) drop( _cons ) cells(b(fmt(3) star) se(par fmt(2)))
				stats(N r2_p TypeLoan Quality, fmt(0 3)
				labels("Observations" "Adjusted R-squared"  "Type loan" "Segment" ))  replace;	
	
# delimit cr				
				
*TABLE 2. BASELINE B*
	
		*1.B.1 - - plain model* 
		*logit NonBankLoan L_OriginalMaturity L_Amount US2YrMarket  mp_shock_b2_90_win   if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
		logit NonBankLoan L_OriginalMaturity L_Amount UST2y UST2y_90  mp_shock_b2_30   if HighestCapitalBank==1 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IB_1
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls=""
				local LoanControls="X"
				local GlobalControls=""

				
				foreach var in  TypeLoan Quality FirmControls LoanControls GlobalControls gof {
					estadd local `var' ``var'':Model_IB_1
				}
	
	
		*1.B.2 - - basic controls* 
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			UST2y UST2y_90  mp_shock_b2_30   if HighestCapitalBank==1 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*US2YrMarket  mp_shock_b2_90_win   if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
			
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IB_2
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls="X"
				local LoanControls="X"
				local GlobalControls=""

				
				foreach var in  TypeLoan Quality gof FirmControls LoanControls GlobalControls {
					estadd local `var' ``var'':Model_IB_2
				}
	
				
	*1.B.3 - - full model* 
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs  mp_shock_b2_30   if HighestCapitalBank==1 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*US2YrMarket  mp_shock_b2_90_win   if HighestCapitalBank==1 & L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
			
			estat gof, group(100)
			
				local gof=`r(p)'
				local gof: di %3.2f `gof'
			
			estimates store Model_IB_3
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls="X"
				local LoanControls="X"
				local GlobalControls="X"

				
				foreach var in  TypeLoan Quality gof FirmControls LoanControls GlobalControls {
					estadd local `var' ``var'':Model_IB_3
				}
				
				
			*Table I*
				# delimit ;
				esttab Model_IB_1 Model_IB_2 Model_IB_3  using robustness_Table_I_B_Baseline_shorterMPwindow.tex, label collabels(none) substitute(\_ _ panel ) 
				title("Monetary policy decisions and nonbank lending")
				 nodepvars mtitles(I II III IV) nonumbers star(* 0.10 ** 0.05 *** 0.01)
				fragment  alignment(S) eqlabels(none) varlabels(
				FedTarget "Fed target rate" NonBankLoan "Non-bank loan" US2YrMarket "2 year interest rates" mp_shock_b2_30 "Pure monetary shock"
				news_shock_b2_30_win "Information shock" MonetaryShock30_win "Monetary policy shock"
				L_OriginalMaturity "Loan maturity" L_Amount "Loan amount" L_OriginalMaturity "Loan maturity" L_NumberLenders "Number lenders"
				Firm_TotalAssets_USbn "Firm assets" Firm_EBITDARatio "Firm EBITDA ratio" Firm_QuickRatio "Firm quick ratio" 
				Firm_LeverageRatio "Firm leverage" Firm_FixedAssetsRatio  "Firm fixed assets ratio"
				Push_InflationExpectation "Inflation expectations" Push_GlobalGDPGrowth "Global GDP growth"
				Push_MerrilLynch_Spread "Merril-Lynch HY spread")			
				nogaps drop( _cons L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio Firm_FixedAssetsRatio lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs) cells(b(fmt(3) star) se(par fmt(2)))
				stats(N r2_p TypeLoan Quality FirmControls LoanControls GlobalControls, fmt(0 3)
				labels("Observations" "Adjusted R-squared" "Type loan" "Segment" "Firm controls" "Loan controls" "Global controls"))  replace;	
				
# delimit cr				

				
*TABLE 3. BASELINE C*
	
		*1.C.1 - - plain model* 
		logit NonBankLoan L_OriginalMaturity L_Amount ///
			UST2y UST2y_90 mp_shock_b2_30 news_shock_b2_30_win  if HighestCapitalBank==1   ///
			 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*& L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_IC_1
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls=""
				local LoanControls="X"
				local GlobalControls=""


				
				foreach var in  TypeLoan Quality gof FirmControls LoanControls GlobalControls {
					estadd local `var' ``var'':Model_IC_1
				}
	

		*1.C.2 - - basic controls* 
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			UST2y UST2y_90 mp_shock_b2_30 news_shock_b2_30_win  if HighestCapitalBank==1   ///
			& L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*& L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_IC_2
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls="X"
				local LoanControls="X"
				local GlobalControls=""


				
				foreach var in  TypeLoan Quality gof FirmControls LoanControls GlobalControls {
					estadd local `var' ``var'':Model_IC_2
				}			
				
				
	*1.C.3 - - full model* 
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs mp_shock_b2_30 news_shock_b2_30_win  if HighestCapitalBank==1   ///
			 & L_TermLoan==1 & Sample_A==1, vce(cluster time)
			*& L_Currency=="U.S. Dollar" & L_TermLoan==1 & Sample_A==1, vce(robust)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_IC_3
		
				local TypeLoan="TL"
				local Quality="All"
				local FirmControls="X"
				local LoanControls="X"
				local GlobalControls="X"


				
				foreach var in  TypeLoan Quality gof FirmControls LoanControls GlobalControls {
					estadd local `var' ``var'':Model_IC_3
				}
				

							
				
				*Table I*
				# delimit ;
				esttab Model_IC_1 Model_IC_2 Model_IC_3  using robustness_Table_I_C_Baseline_shorterMPwindow.tex, label collabels(none) substitute(\_ _ panel ) 
				title("Monetary policy decisions and nonbank lending")
				 nodepvars mtitles(I II III IV) nonumbers star(* 0.10 ** 0.05 *** 0.01)
				fragment  alignment(S) eqlabels(none) varlabels(
				FedTarget "Fed target rate" NonBankLoan "Non-bank loan" US2YrMarket "2 year interest rates" mp_shock_b2_30 "Pure monetary shock"
				news_shock_b2_30_win "Information shock" MonetaryShock30_win "Monetary policy shock"
				L_OriginalMaturity "Loan maturity" L_Amount "Loan amount" L_OriginalMaturity "Loan maturity" L_NumberLenders "Number lenders"
				Firm_TotalAssets_USbn "Firm assets" Firm_EBITDARatio "Firm EBITDA ratio" Firm_QuickRatio "Firm quick ratio" 
				Firm_LeverageRatio "Firm leverage" Firm_FixedAssetsRatio  "Firm fixed assets ratio"
				Push_InflationExpectation "Inflation expectations" Push_GlobalGDPGrowth "Global GDP growth"
				Push_MerrilLynch_Spread "Merril-Lynch HY spread")			
				nogaps drop( _cons L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio Firm_FixedAssetsRatio lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs) cells(b(fmt(3) star) se(par fmt(2)))
				stats(N r2_p TypeLoan Quality FirmControls LoanControls GlobalControls, fmt(0 3)
				labels("Observations" "Adjusted R-squared" "Type loan" "Segment" "Firm controls" "Loan controls" "Global controls"))  replace;	


