

cd "C:/JMCB_Direct_Lenders/"



use "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital.dta", clear

keep LoanDealNumber L_ClosingDate L_Description L_TermLoan_A L_TermLoan_B

save "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_L_Description.dta", replace



use "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_Compressed_FINAL.dta", clear

drop year month day

gen year=year(L_ClosingDate)
gen month=month(L_ClosingDate)
gen day=day(L_ClosingDate)

merge m:1 year month day using "Data/Stock_returns_30_60_90_UST2y_MLHYSpreads.dta"
	drop if _merge==2
	drop _merge

winsor2 SP500_PI_90_xs ,cuts(2.5 97.5) 

merge m:1 year QuarterI using "Data/US_GDP.dta"
	drop if _merge==2
	drop _merge
	
logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
	Firm_LeverageRatio Firm_FixedAssetsRatio    ///
	lgdp_growth ML_HY_Spread  ///
	UST2y UST2y_90 SP500_PI_90_xs MonetaryShock_win if HighestCapitalBank==1, vce(robust)
			
gen Sample_A=1 if e(sample)

keep if Sample_A==1
	
merge 1:1 LoanDealNumber L_ClosingDate using "Data\Dataset_BanerjeeSerena_RegressionsSmAll_FullyUpdate_Capital_L_Description.dta"
	drop if _merge==2
	drop _merge
	
* define cluster for SEs
egen time=group(L_ClosingDate)
egen issuance_ym=group(L_YearIMonth) /* issuance year x month */
egen issuance_yq=group(L_Iquarter)



replace L_TermLoan_B=0 if L_Description=="Term Loan"

replace L_TermLoan_A=1 if L_Description=="Term Loan"
	

cd "Results"



	*Pure monetary and growth shocks*
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs mp_shock_b2_90_win news_shock_b2_90_win  if HighestCapitalBank==1   ///
			& L_TermLoan==1 , vce(cluster time)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_V_1
		
				local TypeLoan="TL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_V_1
				}
				
	
		*Bank term loans*
		logit NonBankLoan  L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			 lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs mp_shock_b2_90_win news_shock_b2_90_win  if HighestCapitalBank==1   ///
			& L_TermLoan==1 & L_TermLoan_A==1, vce(robust)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_V_2
		
				local TypeLoan="BTL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_V_2
				}
				
		*Institutional term loans*
		logit NonBankLoan L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio ///
			Firm_LeverageRatio Firm_FixedAssetsRatio    ///
			lgdp_growth ML_HY_Spread  ///
			UST2y UST2y_90 SP500_PI_90_xs mp_shock_b2_90_win news_shock_b2_90_win  if HighestCapitalBank==1   ///
			& L_TermLoan==1 & L_TermLoan_B==1, vce(cluster time)
			
				estat gof, group(100)
				
				local gof=`r(p)'
				local gof: di %3.2f `gof'


			
				estimates store Model_V_3
		
				local TypeLoan="ITL"
				local Quality="All"

				
				foreach var in  TypeLoan Quality gof {
					estadd local `var' ``var'':Model_V_3
				}
							
						
							
				
				*Table V*
				# delimit ;
				esttab Model_V_1 Model_V_2 Model_V_3 using Table_V_InstitutionalInvestors.tex, label collabels(none) substitute(\_ _ panel ) 
				title("Institutional investors")
				 nodepvars mtitles(I II III) nonumbers star(* 0.10 ** 0.05 *** 0.01)
				fragment  alignment(S) eqlabels(none) varlabels(
				FedTarget "Fed target rate" NonBankLoan "Non-bank loan" UST2y "2 year interest rates" mp_shock_b2_90_win "Pure monetary shock"
				news_shock_b2_90_win "Information shock" MonetaryShock_win "Monetary policy shock"
				L_OriginalMaturity "Loan tenor" L_Amount "Loan amount" L_OriginalMaturity "Loan maturity" L_NumberLenders "Number lenders"
				Firm_TotalAssets_USbn "Firm assets" Firm_EBITDARatio "Firm EBITDA ratio" Firm_QuickRatio "Firm quick ratio" 
				Firm_LeverageRatio "Firm leverage" Firm_FixedAssetsRatio  "Firm Fixed assets ratio)")			
				nogaps drop( _cons UST2y UST2y_90 L_OriginalMaturity L_Amount Firm_TotalAssets_USbn Firm_EBITDARatio Firm_QuickRatio Firm_LeverageRatio Firm_FixedAssetsRatio   
				lgdp_growth ML_HY_Spread SP500_PI_90_xs) cells(b(fmt(3) star) se(par fmt(2)))
				stats(N r2_p  TypeLoan Quality, fmt(0 3)
				labels("Observations" "Adjusted R-squared" "Type loan" "Segment" ))  replace;	


				
	